@@ -449,7 +449,7 @@ class TradeHTTP(HTTPManager):
     """
     ---------------------------------------------------------
     """
-    
+
     def place_spot_order(
         self,
         product_symbol: str,
@@ -525,7 +525,7 @@ class TradeHTTP(HTTPManager):
         if recvWindow is not None:
             payload["recvWindow"] = recvWindow
 
-        res =  self._request(
+        res = self._request(
             method="POST",
             path=SpotTrade.PLACE_SPOT_ORDER,
             query=payload,
@@ -543,7 +543,7 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a market order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param side: str - BUY or SELL
         :param quantity: float - Amount of base asset to buy/sell
@@ -551,7 +551,7 @@ class TradeHTTP(HTTPManager):
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_order(
+        return self.place_spot_order(
             product_symbol=product_symbol,
             side=side,
             type_="MARKET",
@@ -571,14 +571,14 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a market buy order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param quantity: str - Amount of base asset to buy
         :param quoteOrderQty: str - Amount of quote asset to spend
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_market_order(
+        return self.place_spot_market_order(
             product_symbol=product_symbol,
             side="BUY",
             quantity=quantity,
@@ -597,13 +597,13 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a market sell order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param quantity: str - Amount of base asset to sell
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_market_order(
+        return self.place_spot_market_order(
             product_symbol=product_symbol,
             side="SELL",
             quantity=quantity,
@@ -624,7 +624,7 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a limit order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param side: str - BUY or SELL
         :param quantity: str - Amount of base asset to buy/sell
@@ -633,7 +633,7 @@ class TradeHTTP(HTTPManager):
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_order(
+        return self.place_spot_order(
             product_symbol=product_symbol,
             side=side,
             type_="LIMIT",
@@ -655,7 +655,7 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a limit buy order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param quantity: str - Amount of base asset to buy
         :param price: str - Order price
@@ -663,7 +663,7 @@ class TradeHTTP(HTTPManager):
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_limit_order(
+        return self.place_spot_limit_order(
             product_symbol=product_symbol,
             side="BUY",
             quantity=quantity,
@@ -684,7 +684,7 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a limit sell order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param quantity: str - Amount of base asset to sell
         :param price: str - Order price
@@ -692,7 +692,7 @@ class TradeHTTP(HTTPManager):
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_limit_order(
+        return self.place_spot_limit_order(
             product_symbol=product_symbol,
             side="SELL",
             quantity=quantity,
@@ -713,7 +713,7 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a post-only limit order (LIMIT_MAKER)
-        
+
         :param product_symbol: str - Trading pair symbol
         :param side: str - BUY or SELL
         :param quantity: str - Amount of base asset to buy/sell
@@ -721,7 +721,7 @@ class TradeHTTP(HTTPManager):
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_order(
+        return self.place_spot_order(
             product_symbol=product_symbol,
             side=side,
             type_="LIMIT_MAKER",
@@ -741,7 +741,7 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a post-only limit buy order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param quantity: str - Amount of base asset to buy
         :param price: str - Order price
@@ -749,7 +749,7 @@ class TradeHTTP(HTTPManager):
         :param icebergQty: str - Used to create iceberg orders
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_post_only_limit_order(
+        return self.place_spot_post_only_limit_order(
             product_symbol=product_symbol,
             side="BUY",
             quantity=quantity,
@@ -768,14 +768,14 @@ class TradeHTTP(HTTPManager):
     ):
         """
         Place a post-only limit sell order
-        
+
         :param product_symbol: str - Trading pair symbol
         :param quantity: str - Amount of base asset to sell
         :param price: str - Order price
         :param newClientOrderId: str - Unique order ID
         :param newOrderRespType: str - Set response JSON: ACK, RESULT, or FULL
         """
-        return  self.place_spot_post_only_limit_order(
+        return self.place_spot_post_only_limit_order(
             product_symbol=product_symbol,
             side="SELL",
             quantity=quantity,
@@ -783,13 +783,13 @@ class TradeHTTP(HTTPManager):
             newClientOrderId=newClientOrderId,
             newOrderRespType=newOrderRespType,
         )
-    
+
     def cancel_spot_order(
         self,
         product_symbol: str,
         orderId: int = None,
         origClientOrderId: str = None,
-        timestamp: int = int(time.time() * 1000)
+        timestamp: int = int(time.time() * 1000),
     ):
         """
         Cancel an active spot order on Binance.
@@ -802,10 +802,7 @@ class TradeHTTP(HTTPManager):
         :param recvWindow: int - Optional timeout window in ms (max: 60000)
         :return: Binance API response
         """
-        payload = {
-            "symbol": self.ptm.get_exchange_symbol(Common.BINANCE, product_symbol),
-            "timestamp": timestamp
-        }
+        payload = {"symbol": self.ptm.get_exchange_symbol(Common.BINANCE, product_symbol), "timestamp": timestamp}
 
         # 至少要提供 orderId 或 origClientOrderId 其中之一
         if orderId is not None:
@@ -816,32 +813,21 @@ class TradeHTTP(HTTPManager):
             raise ValueError("Must provide either orderId or origClientOrderId to cancel an order.")
 
         # 發送 DELETE 請求
-        res = self._request(
-            method="DELETE",
-            path=SpotTrade.PLACE_SPOT_ORDER,
-            query=payload
-        )
+        res = self._request(method="DELETE", path=SpotTrade.PLACE_SPOT_ORDER, query=payload)
         return res
-    
-    def cancel_all_spot_orders(
-        self,
-        product_symbol: str,
-        timestamp: int = int(time.time() * 1000)
-    ):
+
+    def cancel_all_spot_orders(self, product_symbol: str, timestamp: int = int(time.time() * 1000)):
         """
         Cancel all active spot orders for a symbol on Binance.
 
         :param product_symbol: str - Trading pair symbol (e.g., "BTCUSDT")
         :param timestamp: int - Optional request timeout (max 60000)
         """
-        payload = {
-            "symbol": self.ptm.get_exchange_symbol(Common.BINANCE, product_symbol),
-            "timestamp": timestamp
-        }
+        payload = {"symbol": self.ptm.get_exchange_symbol(Common.BINANCE, product_symbol), "timestamp": timestamp}
 
         res = self._request(
             method="DELETE",
             path=SpotTrade.CANCEL_ALL_SPOT_ORDERS,
             query=payload,
         )
-        return res
\ No newline at end of file
+        return res
